@@ -1,7 +1,7 @@
 package File::Patch::Undoable;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -178,7 +178,7 @@ File::Patch::Undoable - Patch a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.05 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2015-08-17.
+This document describes version 0.06 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2015-09-03.
 
 =head1 FAQ
 
@@ -201,9 +201,8 @@ L<Text::Patch>, L<PatchReader>, L<Text::Patch::Rred>
 
 =head2 patch(%args) -> [status, msg, result, meta]
 
-{en_US Patch a file, with undo support}.
+Patch a file, with undo support.
 
-{en_US 
 On do, will patch file with the supplied patch. On undo, will apply the reverse
 of the patch.
 
@@ -217,7 +216,6 @@ allowed).
 Fixed state: file exists, patch file exists, and patch has been applied.
 
 Fixable state: file exists, patch file exists, and patch has not been applied.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -228,19 +226,17 @@ Arguments ('*' denotes required arguments):
 
 =item * B<file>* => I<str>
 
-{en_US Path to file to be patched}.
+Path to file to be patched.
 
 =item * B<patch>* => I<str>
 
-{en_US Path to patch file}.
+Path to patch file.
 
-{en_US 
 Patch can be in unified or context format, it will be autodetected.
-}
 
 =item * B<reverse> => I<bool> (default: 0)
 
-{en_US Whether to apply reverse of patch}.
+Whether to apply reverse of patch.
 
 =back
 
@@ -287,7 +283,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Patch
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-File-Patch-Undoable>.
+Source repository is at L<https://github.com/perlancar/perl-File-Patch-Undoable>.
 
 =head1 BUGS
 
